===================================
Welcome to *Yangson* documentation!
===================================

Contents:

.. toctree::
   :maxdepth: 2

   introduction
   concepts-terms
   quickstart
   basic
   advanced
   support
   cmdline
   examples
   references
   glossary

##################
Indices and tables
##################

* :ref:`genindex`
* :ref:`modindex`
